package com.ruoyi.demo.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.github.pagehelper.PageInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.demo.entity.Commercial;
import com.ruoyi.demo.entity.bo.CommercialBo;
import com.ruoyi.demo.entity.vo.CommercialVo;
import com.ruoyi.demo.service.CommericalService;
import com.ruoyi.system.domain.SysOperLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 商户管理
 */
@RestController
@RequestMapping("/commercial")
public class CommercialController {
    @Autowired
    CommericalService commericalService;

    /**
     * 新增商户
     * @param commercialVo app信息接收体
     * @return
     */
    @SaCheckPermission("szzs:commerce:add")
    @PostMapping("/addCommercial")
    public R addCommercial(@RequestBody @Validated(value = {AddGroup.class}) CommercialVo commercialVo){
        commericalService.addCommercial(commercialVo);
        return R.ok();
    }

    /**
     * 修改商户信息
     * @param commercialVo 商户信息接收体
     * @return
     */
    @SaCheckPermission("szzs:commerce:update")
    @PutMapping("/updateCommercial")
    public R updateCommercial(@RequestBody @Validated(value = {EditGroup.class}) CommercialVo commercialVo){
        commericalService.updateCommercial(commercialVo);
        return R.ok();
    }

    /**
     * 删除商户
     * @param commercialIds 待删除商户Id
     * @return
     */
    @SaCheckPermission("szzs:commerce:delete")
    @DeleteMapping("/deleteCommercial")
    public R deleteCommercial(@NotEmpty(message = "待删除商户Id不能为空") String[] commercialIds){
        R r = commericalService.deleteCommercial(commercialIds);
        return r;
    }

    /**
     * 获取商户详细信息
     * @param commercialId 商户Id
     * @return
     */
    @SaCheckPermission("szzs:commerce:query")
    @GetMapping("/getCommercial")
    public R getCommercial(@NotBlank(message = "商户Id不能为空") String commercialId){
        Commercial commercial = commericalService.getCommercial(commercialId);
        return R.ok(commercial);
    }

    /**
     * 获取商户列表
     * @param commercialVo 商户信息接收体
     * @return
     */
    @SaCheckPermission("szzs:commerce:list")
    @GetMapping("/getCommercialList")
    public R getCommercialList(CommercialVo commercialVo){
        HashMap commercialList = commericalService.getCommercialList(commercialVo);
        return R.ok(commercialList);
    }

    /**
     * 导出商户列表
     */
    @Log(title = "商户列表", businessType = BusinessType.EXPORT)
    @SaCheckPermission("szzs:commerce:export")
    @PostMapping("/export")
    public void export(@RequestBody CommercialVo commercialVo, HttpServletResponse response) {
        HashMap commercialList = commericalService.getCommercialList(commercialVo);
        ArrayList<CommercialBo> data = (ArrayList<CommercialBo>) commercialList.getOrDefault("data", new ArrayList<CommercialBo>());
        ExcelUtil.exportExcel(data, "商户列表", CommercialBo.class, response);
    }

    /**
     * 获取可选择的商户Id、名称
     * @return
     */
    @SaCheckPermission("szzs:commerce:query")
    @GetMapping("/getCommercialName")
    public R getCommercialName(){
        List<Commercial> commercialName = commericalService.getCommercialName();
        return R.ok(commercialName);
    }
}
