package com.ruoyi.demo.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.demo.entity.Goods;
import com.ruoyi.demo.entity.MyPage;
import com.ruoyi.demo.entity.bo.GoodsBo;
import com.ruoyi.demo.entity.bo.GoodsDeleteBo;
import com.ruoyi.demo.entity.bo.PlanBo;
import com.ruoyi.demo.entity.vo.GoodsListVo;
import com.ruoyi.demo.service.GoodsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;

/**
 * 商品管理
 */
@RestController
@RequestMapping("/goods")
public class GoodsController {
    @Autowired
    GoodsService goodsService;

    @SaCheckPermission("szzs:goods:add")
    @PostMapping()
    public R addGoods(@RequestBody Goods goods){
        int i = goodsService.addGoods(goods);
        if (i == 2)
            return R.ok("已存在该商品");
        if (i == 1)
            return R.ok("添加成功");
        return R.fail("添加失败");
    }

    @SaCheckPermission("szzs:goods:delete")
    @DeleteMapping()
    public R deleteGoods(@RequestBody GoodsDeleteBo bo){
        int i = goodsService.deleteGoods(bo);
        if (i == 1)
            return R.ok("删除成功");
        return R.fail("删除失败");
    }

    /**
     * 查询商品信息列表
     * @param bo 请求体
     * @return
     */
    @SaCheckPermission("szzs:goods:list")
    @PostMapping("/list")
    public R goodsList(@RequestBody PlanBo bo){
        if (bo.getStartTime() != null && bo.getEndTime() != null && bo.getStartTime().compareTo(bo.getEndTime()) > 0)
            return R.fail("起始时间不能大于结束时间");
        return R.ok(goodsService.getGoodsList(bo));
    }

    @SaCheckPermission("szzs:goods:query")
    @PostMapping("/detail")
    public R goodsDetail(@RequestBody GoodsBo bo){
        return R.ok(goodsService.getGoodsDetail(bo));
    }

    @SaCheckPermission("szzs:goods:update")
    @PutMapping()
    public R editGoods(@RequestBody Goods goods){
        int i = goodsService.editGoods(goods);
        if (i == 1)
            return R.ok("修改成功");
        return R.fail("修改失败");
    }

    /**
     * 导出商品信息列表
     *
     * @param bo body参数
     * @return
     */
    @Log(title = "商品列表", businessType = BusinessType.EXPORT)
    @SaCheckPermission("szzs:goods:export")
    @PostMapping("/export")
    public void export(@RequestBody PlanBo bo, HttpServletResponse response) {
        if (bo.getStartTime() != null && bo.getEndTime() != null && bo.getStartTime().compareTo(bo.getEndTime()) > 0)
            throw new ServiceException("起始时间不能大于结束时间");
        MyPage<GoodsListVo> goodsList = goodsService.getGoodsList(bo);
        ExcelUtil.exportExcel(goodsList.getRecords(), "商品列表", GoodsListVo.class, response);
    }
}
